Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(466)

Unified Diff: ash/common/accelerators/accelerator_controller.h

Issue 2586333003: Make mash register initial batch of accelerators in single shot. (Closed)
Patch Set: Remove temporary vector. Add comments. Add AddAcceleratorToVector to use in OnAcceleratorRegistered… Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/accelerators/accelerator_controller.h
diff --git a/ash/common/accelerators/accelerator_controller.h b/ash/common/accelerators/accelerator_controller.h
index 38b9007edbebd90702c6fd39435788865b64e1ff..eefe9de134233d4c26f4f3a22e1e51825bf1d20d 100644
--- a/ash/common/accelerators/accelerator_controller.h
+++ b/ash/common/accelerators/accelerator_controller.h
@@ -10,6 +10,7 @@
#include <map>
#include <memory>
#include <set>
+#include <vector>
#include "ash/ash_export.h"
#include "ash/common/accelerators/accelerator_table.h"
@@ -60,10 +61,10 @@ class ASH_EXPORT AcceleratorController
RESTRICTION_PREVENT_PROCESSING_AND_PROPAGATION
};
// Registers a global keyboard accelerator for the specified target. If
// multiple targets are registered for an accelerator, a target registered
mfomitchev 2016/12/22 21:18:55 If multiple targets are registered for any given a
thanhph 2016/12/24 18:52:16 Done.
// later has higher priority.
- void Register(const ui::Accelerator& accelerator,
+ void Register(const std::vector<ui::Accelerator>& accelerators,
ui::AcceleratorTarget* target);
// Unregisters the specified keyboard accelerator for the specified target.
@@ -60,10 +61,10 @@ class ASH_EXPORT AcceleratorController
RESTRICTION_PREVENT_PROCESSING_AND_PROPAGATION
};
- // Registers a global keyboard accelerator for the specified target. If
- // multiple targets are registered for an accelerator, a target registered
+ // Registers global keyboard accelerators for the specified target. If
+ // multiple targets are registered for accelerators, a target registered
mfomitchev 2016/12/22 21:18:55 If multiple targets are registered for any given a
thanhph 2016/12/24 18:52:16 Done.

Powered by Google App Engine
This is Rietveld 408576698